"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QSlider(QAbstractSlider):
    """
    https://doc.qt.io/qt-6/qslider.html

    **Detailed Description**

    ![](images/windows-slider.png)

    The slider is the classic widget for controlling a bounded value. It lets
    the user move a slider handle along a horizontal or vertical groove and
    translates the handle's position into an integer value within the legal
    range.

    QSlider has very few of its own functions; most of the functionality is in
    **QAbstractSlider** . The most useful functions are **setValue** () to set
    the slider directly to some value; **triggerAction** () to simulate the
    effects of clicking (useful for shortcut keys); **setSingleStep** (),
    **setPageStep** () to set the steps; and **setMinimum** () and
    **setMaximum** () to define the range of the scroll bar.

    QSlider provides methods for controlling tickmarks. You can use
    **setTickPosition** () to indicate where you want the tickmarks to be,
    **setTickInterval** () to indicate how many of them you want. the currently
    set tick position and interval can be queried using the **tickPosition** ()
    and **tickInterval** () functions, respectively.

    QSlider inherits a comprehensive set of signals:

    SignalDescription
    **valueChanged** ()Emitted when the slider's value has
    changed. The tracking() determines whether this signal is emitted during
    user interaction.
    **sliderPressed** ()Emitted when the user starts to drag
    the slider.
    **sliderMoved** ()Emitted when the user drags the slider.
    **sliderReleased** ()Emitted when the user releases the slider.

    QSlider only provides integer ranges. Note that although QSlider handles
    very large numbers, it becomes difficult for users to use a slider
    accurately for very large ranges.

    A slider accepts focus on Tab and provides both a mouse wheel and a keyboard
    interface. The keyboard interface is the following:

    * Left/Right move a horizontal slider by one single step.
      * Up/Down move a
    vertical slider by one single step.
      * PageUp moves up one page.
      *
    PageDown moves down one page.
      * Home moves to the start (minimum).
      * End
    moves to the end (maximum).

    **See also** **QScrollBar** , **QSpinBox** , **QDial** , **GUI Design
    Handbook: Slider** , and **Sliders Example** .
    """

    class TickPosition(enum.Enum):
        NoTicks: QSlider = ...
        TicksAbove: QSlider = ...
        TicksLeft: QSlider = ...
        TicksBelow: QSlider = ...
        TicksRight: QSlider = ...
        TicksBothSides: QSlider = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#QSlider

        **QSlider::QSlider(QWidget * parent = nullptr)**

        Constructs a vertical slider with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, orientation: QtCore.Qt.Orientation, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#QSlider-1

        **QSlider::QSlider(Qt::Orientation orientation , QWidget * parent =
        nullptr)**

        Constructs a slider with the given **parent**. The **orientation**
        parameter determines whether the slider is horizontal or vertical; the
        valid values are **Qt::Vertical**  and **Qt::Horizontal** .
        """
        ...

    def mouseMoveEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#mouseMoveEvent

        **[override virtual protected] void QSlider::mouseMoveEvent(QMouseEvent
        * ev )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#mouseReleaseEvent

        **[override virtual protected] void
        QSlider::mouseReleaseEvent(QMouseEvent * ev )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#mousePressEvent

        **[override virtual protected] void QSlider::mousePressEvent(QMouseEvent
        * ev )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def paintEvent(self, ev: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#paintEvent

        **[override virtual protected] void QSlider::paintEvent(QPaintEvent * ev
        )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionSlider") -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#initStyleOption

        **[virtual protected] void QSlider::initStyleOption(QStyleOptionSlider *
        option ) const**

        Initialize **option** with the values from this **QSlider** . This
        method is useful for subclasses when they need a **QStyleOptionSlider**
        , but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qslider.html#event

        **[override virtual] bool QSlider::event(QEvent * event )**

        Reimplements: **QAbstractSlider::event** (QEvent *e).
        """
        ...

    def tickInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qslider.html#tickInterval-prop

        **tickInterval : int**

        This property holds the interval between tickmarks

        This is a value interval, not a pixel interval. If it is 0, the slider
        will choose between singleStep and pageStep.

        The default value is 0.

        **Access functions:**

        int **tickInterval** () const
        void **setTickInterval** (int **ti** )

        **See also** **tickPosition** , **singleStep** , and **pageStep** .
        """
        ...

    def setTickInterval(self, ti: int) -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#tickInterval-prop

        **tickInterval : int**

        This property holds the interval between tickmarks

        This is a value interval, not a pixel interval. If it is 0, the slider
        will choose between singleStep and pageStep.

        The default value is 0.

        **Access functions:**

        int **tickInterval** () const
        void **setTickInterval** (int **ti** )

        **See also** **tickPosition** , **singleStep** , and **pageStep** .
        """
        ...

    def tickPosition(self) -> "QSlider.TickPosition":
        """
        https://doc.qt.io/qt-6/qslider.html#tickPosition-prop

        **tickPosition : TickPosition**

        This property holds the tickmark position for this slider

        The valid values are described by the **QSlider::TickPosition**  enum.

        The default value is **QSlider::NoTicks** .

        **Access functions:**

        QSlider::TickPosition **tickPosition** () const
        void
        **setTickPosition** (QSlider::TickPosition **position** )

        **See also** **tickInterval** .

        **Member Function Documentation**
        """
        ...

    def setTickPosition(self, position: "QSlider.TickPosition") -> None:
        """
        https://doc.qt.io/qt-6/qslider.html#tickPosition-prop

        **tickPosition : TickPosition**

        This property holds the tickmark position for this slider

        The valid values are described by the **QSlider::TickPosition**  enum.

        The default value is **QSlider::NoTicks** .

        **Access functions:**

        QSlider::TickPosition **tickPosition** () const
        void
        **setTickPosition** (QSlider::TickPosition **position** )

        **See also** **tickInterval** .

        **Member Function Documentation**
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qslider.html#minimumSizeHint

        **[override virtual] QSize QSlider::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qslider.html#sizeHint

        **[override virtual] QSize QSlider::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets


class QDesignerContainerExtension(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignercontainerextension.html

    **Detailed Description**

    ![](images/containerextension-example.png)

    QDesignerContainerExtension provide an interface for creating custom
    container extensions. A container extension consists of a collection of
    functions that **Qt Designer** needs to manage a multi-page container
    plugin, and a list of the container's pages.

    **Warning:** This is **not** an extension for container plugins in general,
    only custom **multi-page** containers.

    To create a container extension, your extension class must inherit from both
    **QObject**  and QDesignerContainerExtension. For example:

    class MyContainerExtension : public **QObject** ,
               public
    QDesignerContainerExtension
        {
            Q_OBJECT
    Q_INTERFACES(QDesignerContainerExtension)

        public:
    MyContainerExtension(MyCustomWidget *widget,
    **QObject**  *parent = 0);
            int count() const;
            **QWidget**
    *widget(int index) const;
            int currentIndex() const;
            void
    setCurrentIndex(int index);
            void addWidget(**QWidget**  *widget);
    void insertWidget(int index, **QWidget**  *widget);
            void remove(int
    index);

        private:
            MyCustomWidget *myWidget;
        };

    Since we are implementing an interface, we must ensure that it's made known
    to the meta object system using the **Q_INTERFACES** () macro. This enables
    **Qt Designer** to use the **qobject_cast** () function to query for
    supported interfaces using nothing but a **QObject**  pointer.

    You must reimplement several functions to enable **Qt Designer** to manage a
    custom multi-page container widget: **Qt Designer** uses **count** () to
    keep track of the number pages in your container, **widget** () to return
    the page at a given index in the list of the container's pages, and
    **currentIndex** () to return the list index of the selected page. **Qt
    Designer** uses the **addWidget** () function to add a given page to the
    container, expecting it to be appended to the list of pages, while it
    expects the **insertWidget** () function to add a given page to the
    container by inserting it at a given index.

    In **Qt Designer** the extensions are not created until they are required.
    For that reason you must also create a **QExtensionFactory** , i.e a class
    that is able to make an instance of your extension, and register it using
    **Qt Designer** 's **extension manager** .

    When a container extension is required, **Qt Designer** 's **extension
    manager**  will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until the first one that
    is able to create a container extension, is found. This factory will then
    create the extension for the plugin.

    There are four available types of extensions in **Qt Designer** :
    QDesignerContainerExtension , **QDesignerMemberSheetExtension** ,
    **QDesignerPropertySheetExtension**  and **QDesignerTaskMenuExtension** .
    **Qt Designer** 's behavior is the same whether the requested extension is
    associated with a multi page container, a member sheet, a property sheet or
    a task menu.

    The **QExtensionFactory**  class provides a standard extension factory, and
    can also be used as an interface for custom extension factories. You can
    either create a new **QExtensionFactory**  and reimplement the
    **QExtensionFactory::createExtension** () function. For example:

    **QObject**  *ANewExtensionFactory::createExtension(**QObject**  *object,
    const **QString**  &iid, **QObject**  *parent) const
        {
            if (iid
    != Q_TYPEID(QDesignerContainerExtension))
                return 0;
    if (MyCustomWidget *widget = qobject_cast<MyCustomWidget*>
    (object))
                return new MyContainerExtension(widget, parent);
    return 0;
        }

    Or you can use an existing factory, expanding the
    **QExtensionFactory::createExtension** () function to make the factory able
    to create a container extension as well. For example:

    **QObject**  *AGeneralExtensionFactory::createExtension(**QObject**
    *object,
                const **QString**  &iid, **QObject**  *parent) const
    {
            MyCustomWidget *widget = qobject_cast<MyCustomWidget*>(object);
    if (widget && (iid == Q_TYPEID(**QDesignerTaskMenuExtension** ))) {
    return new MyTaskMenuExtension(widget, parent);

            } else if
    (widget && (iid == Q_TYPEID(QDesignerContainerExtension))) {
    return new MyContainerExtension(widget, parent);

            } else {
    return 0;
            }
        }

    For a complete example using the QDesignerContainerExtension class, see the
    **Container Extension example** . The example shows how to create a custom
    multi-page plugin for **Qt Designer**.

    **See also** **QExtensionFactory** , **QExtensionManager** , and **Creating
    Custom Widget Extensions** .
    """

    def __init__(self) -> None:
        ...

    def canRemove(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#canRemove

        **[pure virtual, since 5.0] bool
        QDesignerContainerExtension::canRemove(int index ) const**

        Returns whether the widget at the given **index** can be removed. This
        determines whether the context menu option to remove the current page is
        enabled.

        This should return false for containers that have a single, fixed page,
        for example **QScrollArea**  or **QDockWidget** .

        This function was introduced in Qt 5.0.

        **See also** **remove** () and **canAddWidget** ().
        """
        ...

    def canAddWidget(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#canAddWidget

        **[pure virtual, since 5.0] bool
        QDesignerContainerExtension::canAddWidget() const**

        Returns whether a widget can be added. This determines whether the
        context menu options to add or insert pages are enabled.

        This should return false for containers that have a single, fixed page,
        for example **QScrollArea**  or **QDockWidget** .

        This function was introduced in Qt 5.0.

        **See also** **addWidget** () and **canRemove** ().
        """
        ...

    def remove(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#remove

        **[pure virtual] void QDesignerContainerExtension::remove(int index )**

        Removes the page at the given **index** from the extension's list of
        pages.

        **See also** **addWidget** () and **insertWidget** ().
        """
        ...

    def insertWidget(self, index: int, widget: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#insertWidget

        **[pure virtual] void QDesignerContainerExtension::insertWidget(int
        index , QWidget * page )**

        Adds the given **page** to the container by inserting it at the given
        **index** in the extension's list of pages.

        **See also** **addWidget** (), **remove** (), and **widget** ().
        """
        ...

    def addWidget(self, widget: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#addWidget

        **[pure virtual] void QDesignerContainerExtension::addWidget(QWidget *
        page )**

        Adds the given **page** to the container by appending it to the
        extension's list of pages.

        **See also** **insertWidget** (), **remove** (), and **widget** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#setCurrentIndex

        **[pure virtual] void QDesignerContainerExtension::setCurrentIndex(int
        index )**

        Sets the currently selected page in the container to be the page at the
        given **index** in the extension's list of pages.

        **See also** **currentIndex** ().
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#currentIndex

        **[pure virtual] int QDesignerContainerExtension::currentIndex() const**

        Returns the index of the currently selected page in the container.

        **See also** **setCurrentIndex** ().
        """
        ...

    def widget(self, index: int) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#widget

        **[pure virtual] QWidget *QDesignerContainerExtension::widget(int index
        ) const**

        Returns the page at the given **index** in the extension's list of
        pages.

        **See also** **addWidget** () and **insertWidget** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignercontainerextension.html#count

        **[pure virtual] int QDesignerContainerExtension::count() const**

        Returns the number of pages in the container.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QContextMenuEvent(QInputEvent):
    """
    https://doc.qt.io/qt-6/qcontextmenuevent.html

    **Detailed Description**

    Context menu events are sent to widgets when a user performs an action
    associated with opening a context menu. The actions required to open context
    menus vary between platforms; for example, on Windows, pressing the menu
    button or clicking the right mouse button will cause this event to be sent.

    When this event occurs it is customary to show a **QMenu**  with a context
    menu, if this is relevant to the context.
    """

    class Reason(enum.Enum):
        Mouse: QContextMenuEvent = ...
        Keyboard: QContextMenuEvent = ...
        Other: QContextMenuEvent = ...

    @typing.overload
    def __init__(
        self,
        reason: "QContextMenuEvent.Reason",
        pos: QtCore.QPoint,
        globalPos: QtCore.QPoint,
        modifiers: QtCore.Qt.KeyboardModifier = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#QContextMenuEvent-2

        **QContextMenuEvent::QContextMenuEvent(QContextMenuEvent::Reason reason
        , const QPoint & pos , const QPoint & globalPos , Qt::KeyboardModifiers
        modifiers = Qt::NoModifier)**

        Constructs a context menu event object with the accept parameter flag
        set to false.

        The **reason** parameter must be **QContextMenuEvent::Mouse**  or
        **QContextMenuEvent::Keyboard** .

        The **pos** parameter specifies the mouse position relative to the
        receiving widget. **globalPos** is the mouse position in absolute
        coordinates. The **modifiers** holds the keyboard modifiers.
        """
        ...

    @typing.overload
    def __init__(self, reason: "QContextMenuEvent.Reason", pos: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#QContextMenuEvent-3

        **QContextMenuEvent::QContextMenuEvent(QContextMenuEvent::Reason reason
        , const QPoint & pos )**

        Constructs a context menu event object with the accept parameter flag
        set to false.

        The **reason** parameter must be **QContextMenuEvent::Mouse**  or
        **QContextMenuEvent::Keyboard** .

        The **pos** parameter specifies the mouse position relative to the
        receiving widget.

        The **globalPos** () is initialized to **QCursor::pos** (), which may
        not be appropriate. Use the other constructor to specify the global
        position explicitly.
        """
        ...

    def clone(self) -> "QContextMenuEvent":
        ...

    def reason(self) -> "QContextMenuEvent.Reason":
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#reason

        **QContextMenuEvent::Reason QContextMenuEvent::reason() const**

        Returns the reason for this context event.
        """
        ...

    def globalPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#globalPos

        **const QPoint &QContextMenuEvent::globalPos() const**

        Returns the global position of the mouse pointer at the time of the
        event.

        **See also** **x** (), **y** (), and **pos** ().
        """
        ...

    def pos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#pos

        **const QPoint &QContextMenuEvent::pos() const**

        Returns the position of the mouse pointer relative to the widget that
        received the event.

        **See also** **x** (), **y** (), and **globalPos** ().
        """
        ...

    def globalY(self) -> int:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#globalY

        **int QContextMenuEvent::globalY() const**

        Returns the global y position of the mouse pointer at the time of the
        event.

        **See also** **globalX** () and **globalPos** ().
        """
        ...

    def globalX(self) -> int:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#globalX

        **int QContextMenuEvent::globalX() const**

        Returns the global x position of the mouse pointer at the time of the
        event.

        **See also** **globalY** () and **globalPos** ().
        """
        ...

    def y(self) -> int:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#y

        **int QContextMenuEvent::y() const**

        Returns the y position of the mouse pointer, relative to the widget that
        received the event.

        **See also** **x** () and **pos** ().
        """
        ...

    def x(self) -> int:
        """
        https://doc.qt.io/qt-6/qcontextmenuevent.html#x

        **int QContextMenuEvent::x() const**

        Returns the x position of the mouse pointer, relative to the widget that
        received the event.

        **See also** **y** () and **pos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QLibrary(QObject):
    """
    https://doc.qt.io/qt-6/qlibrary.html

    **Detailed Description**

    An instance of a QLibrary object operates on a single shared object file
    (which we call a "library", but is also known as a "DLL"). A QLibrary
    provides access to the functionality in the library in a platform
    independent way. You can either pass a file name in the constructor, or set
    it explicitly with **setFileName** (). When loading the library, QLibrary
    searches in all the system-specific library locations (e.g.
    `LD_LIBRARY_PATH` on Unix), unless the file name has an absolute path.

    If the file name is an absolute path then an attempt is made to load this
    path first. If the file cannot be found, QLibrary tries the name with
    different platform-specific file prefixes, like "lib" on Unix and Mac, and
    suffixes, like ".so" on Unix, ".dylib" on the Mac, or ".dll" on Windows.

    If the file path is not absolute then QLibrary modifies the search order to
    try the system-specific prefixes and suffixes first, followed by the file
    path specified.

    This makes it possible to specify shared libraries that are only identified
    by their basename (i.e. without their suffix), so the same code will work on
    different operating systems yet still minimise the number of attempts to
    find the library.

    The most important functions are **load** () to dynamically load the library
    file, **isLoaded** () to check whether loading was successful, and
    **resolve** () to resolve a symbol in the library. The **resolve** ()
    function implicitly tries to load the library if it has not been loaded yet.
    Multiple instances of QLibrary can be used to access the same physical
    library. Once loaded, libraries remain in memory until the application
    terminates. You can attempt to unload a library using **unload** (), but if
    other instances of QLibrary are using the same library, the call will fail,
    and unloading will only happen when every instance has called **unload** ().

    A typical use of QLibrary is to resolve an exported symbol in a library, and
    to call the C function that this symbol represents. This is called "explicit
    linking" in contrast to "implicit linking", which is done by the link step
    in the build process when linking an executable against a library.

    The following code snippet loads a library, resolves the symbol "mysymbol",
    and calls the function if everything succeeded. If something goes wrong,
    e.g. the library file does not exist or the symbol is not defined, the
    function pointer will be `nullptr` and won't be called.

    **QLibrary**  myLib("mylib");
        typedef void (*MyPrototype)();
    MyPrototype myFunction = (MyPrototype) myLib.resolve("mysymbol");
        if
    (myFunction)
            myFunction();

    The symbol must be exported as a C function from the library for **resolve**
    () to work. This means that the function must be wrapped in an `extern "C"`
    block if the library is compiled with a C++ compiler. On Windows, this also
    requires the use of a `dllexport` macro; see **resolve** () for the details
    of how this is done. For convenience, there is a static **resolve** ()
    function which you can use if you just want to call a function in a library
    without explicitly loading the library first:

    typedef void (*MyPrototype)();
        MyPrototype myFunction =
    (MyPrototype) **QLibrary** ::resolve("mylib", "mysymbol");
        if
    (myFunction)
            myFunction();

    **See also** **QPluginLoader** .
    """

    class LoadHint(enum.Flag):
        ResolveAllSymbolsHint: QLibrary = ...
        ExportExternalSymbolsHint: QLibrary = ...
        LoadArchiveMemberHint: QLibrary = ...
        PreventUnloadHint: QLibrary = ...
        DeepBindHint: QLibrary = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#QLibrary

        **QLibrary::QLibrary(QObject * parent = nullptr)**

        Constructs a library with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#QLibrary-1

        **QLibrary::QLibrary(const QString & fileName , QObject * parent =
        nullptr)**

        Constructs a library object with the given **parent** that will load the
        library specified by **fileName**.

        We recommend omitting the file's suffix in **fileName** , since QLibrary
        will automatically look for the file with the appropriate suffix in
        accordance with the platform, e.g. ".so" on Unix, ".dylib" on macOS and
        iOS, and ".dll" on Windows. (See **fileName** .)
        """
        ...

    @typing.overload
    def __init__(
        self, fileName: str, verNum: int, parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#QLibrary-2

        **QLibrary::QLibrary(const QString & fileName , int verNum , QObject *
        parent = nullptr)**

        Constructs a library object with the given **parent** that will load the
        library specified by **fileName** and major version number **verNum**.
        Currently, the version number is ignored on Windows.

        We recommend omitting the file's suffix in **fileName** , since QLibrary
        will automatically look for the file with the appropriate suffix in
        accordance with the platform, e.g. ".so" on Unix, ".dylib" on macOS and
        iOS, and ".dll" on Windows. (See **fileName** .)
        """
        ...

    @typing.overload
    def __init__(
        self, fileName: str, version: str, parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#QLibrary-3

        **QLibrary::QLibrary(const QString & fileName , const QString & version
        , QObject * parent = nullptr)**

        Constructs a library object with the given **parent** that will load the
        library specified by **fileName** and full version number **version**.
        Currently, the version number is ignored on Windows.

        We recommend omitting the file's suffix in **fileName** , since QLibrary
        will automatically look for the file with the appropriate suffix in
        accordance with the platform, e.g. ".so" on Unix, ".dylib" on macOS and
        iOS, and ".dll" on Windows. (See **fileName** .)
        """
        ...

    def setLoadHints(self, hints: "QLibrary.LoadHint") -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#loadHints-prop

        **loadHints : LoadHints**

        Give the **load** () function some hints on how it should behave.

        You can give some hints on how the symbols are resolved. Usually, the
        symbols are not resolved at load time, but resolved lazily, (that is,
        when **resolve** () is called). If you set the loadHints to
        **ResolveAllSymbolsHint** , then all symbols will be resolved at load
        time if the platform supports it.

        Setting **ExportExternalSymbolsHint**  will make the external symbols in
        the library available for resolution in subsequent loaded libraries.

        If **LoadArchiveMemberHint**  is set, the file name is composed of two
        components: A path which is a reference to an archive file followed by
        the second component which is the reference to the archive member. For
        instance, the **fileName**  `libGL.a(shr_64.o)` will refer to the
        library `shr_64.o` in the archive file named `libGL.a`. This is only
        supported on the AIX platform.

        The interpretation of the load hints is platform dependent, and if you
        use it you are probably making some assumptions on which platform you
        are compiling for, so use them only if you understand the consequences
        of them.

        By default, none of these flags are set, so libraries will be loaded
        with lazy symbol resolution, and will not export external symbols for
        resolution in other dynamically-loaded libraries.

        **Note:** Setting this property after the library has been loaded has no
        effect and loadHints() will not reflect those changes.

        **Note:** This property is shared among all **QLibrary**  instances that
        refer to the same library.

        **Access functions:**

        QLibrary::LoadHints **loadHints** () const
        void **setLoadHints**
        (QLibrary::LoadHints **hints** )

        **Member Function Documentation**
        """
        ...

    @typing.overload
    def setFileNameAndVersion(self, fileName: str, verNum: int) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#setFileNameAndVersion

        **void QLibrary::setFileNameAndVersion(const QString & fileName , int
        versionNumber )**

        Sets the **fileName**  property and major version number to **fileName**
        and **versionNumber** respectively. The **versionNumber** is ignored on
        Windows.

        **See also** **setFileName** ().
        """
        ...

    @typing.overload
    def setFileNameAndVersion(self, fileName: str, version: str) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#setFileNameAndVersion-1

        **void QLibrary::setFileNameAndVersion(const QString & fileName , const
        QString & version )**

        Sets the **fileName**  property and full version number to **fileName**
        and **version** respectively. The **version** parameter is ignored on
        Windows.

        **See also** **setFileName** ().
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qlibrary.html#fileName-prop

        **fileName : QString**

        This property holds the file name of the library

        We recommend omitting the file's suffix in the file name, since
        **QLibrary**  will automatically look for the file with the appropriate
        suffix (see **isLibrary** ()).

        When loading the library, **QLibrary**  searches in all system-specific
        library locations (for example, `LD_LIBRARY_PATH` on Unix), unless the
        file name has an absolute path. After loading the library successfully,
        fileName() returns the fully-qualified file name of the library,
        including the full path to the library if one was given in the
        constructor or passed to setFileName().

        For example, after successfully loading the "GL" library on Unix
        platforms, fileName() will return "libGL.so". If the file name was
        originally passed as "/usr/lib/libGL", fileName() will return
        "/usr/lib/libGL.so".

        **Access functions:**

        QString **fileName** () const
        void **setFileName** (const QString &
        **fileName** )
        """
        ...

    @staticmethod
    def isLibrary(fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qlibrary.html#isLibrary

        **[static] bool QLibrary::isLibrary(const QString & fileName )**

        Returns `true` if **fileName** has a valid suffix for a loadable
        library; otherwise returns `false`.

        PlatformValid suffixes
        Windows`.dll`, `.DLL`
        Unix/Linux`.so`
        AIX`.a`
        HP-UX`.sl`, `.so` (HP-UXi)
        macOS and iOS`.dylib`, `.bundle`,
        `.so`

        Trailing versioning numbers on Unix are ignored.
        """
        ...

    def unload(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlibrary.html#unload

        **bool QLibrary::unload()**

        Unloads the library and returns `true` if the library could be unloaded;
        otherwise returns `false`.

        This happens automatically on application termination, so you shouldn't
        normally need to call this function.

        If other instances of **QLibrary**  are using the same library, the call
        will fail, and unloading will only happen when every instance has called
        unload().

        Note that on Mac OS X 10.3 (Panther), dynamic libraries cannot be
        unloaded.

        **See also** **resolve** () and **load** ().
        """
        ...

    @typing.overload
    def resolve(self, symbol: str) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qlibrary.html#resolve

        **QFunctionPointer QLibrary::resolve(const char * symbol )**

        Returns the address of the exported symbol **symbol**. The library is
        loaded if necessary. The function returns `nullptr` if the symbol could
        not be resolved or if the library could not be loaded.

        Example:

        typedef int (*AvgFunction)(int, int);

            AvgFunction avg =
        (AvgFunction) library->resolve("avg");
            if (avg)
                return
        avg(5, 8);
            else
                return -1;

        The symbol must be exported as a C function from the library. This means
        that the function must be wrapped in an `extern "C"` if the library is
        compiled with a C++ compiler. On Windows you must also explicitly export
        the function from the DLL using the `__declspec(dllexport)` compiler
        directive, for example:

        extern "C" MY_EXPORT int avg(int a, int b)
            {
                return (a + b)
        / 2;
            }

        with `MY_EXPORT` defined as

        #ifdef Q_OS_WIN
            #define MY_EXPORT __declspec(dllexport)
            #else
        #define MY_EXPORT
            #endif
        """
        ...

    @typing.overload
    @staticmethod
    def resolve(fileName: str, symbol: str) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qlibrary.html#resolve-1

        **[static] QFunctionPointer QLibrary::resolve(const QString & fileName ,
        const char * symbol )**

        This is an overloaded function.

        Loads the library **fileName** and returns the address of the exported
        symbol **symbol**. Note that **fileName** should not include the
        platform-specific file suffix; (see **fileName** ). The library remains
        loaded until the application exits.

        The function returns `nullptr` if the symbol could not be resolved or if
        the library could not be loaded.

        **See also** **resolve** ().
        """
        ...

    @typing.overload
    @staticmethod
    def resolve(fileName: str, verNum: int, symbol: str) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qlibrary.html#resolve-2

        **[static] QFunctionPointer QLibrary::resolve(const QString & fileName ,
        int verNum , const char * symbol )**

        This is an overloaded function.

        Loads the library **fileName** with major version number **verNum** and
        returns the address of the exported symbol **symbol**. Note that
        **fileName** should not include the platform-specific file suffix; (see
        **fileName** ). The library remains loaded until the application exits.
        **verNum** is ignored on Windows.

        The function returns `nullptr` if the symbol could not be resolved or if
        the library could not be loaded.

        **See also** **resolve** ().
        """
        ...

    @typing.overload
    @staticmethod
    def resolve(fileName: str, version: str, symbol: str) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qlibrary.html#resolve-3

        **[static] QFunctionPointer QLibrary::resolve(const QString & fileName ,
        const QString & version , const char * symbol )**

        This is an overloaded function.

        Loads the library **fileName** with full version number **version** and
        returns the address of the exported symbol **symbol**. Note that
        **fileName** should not include the platform-specific file suffix; (see
        **fileName** ). The library remains loaded until the application exits.
        **version** is ignored on Windows.

        The function returns `nullptr` if the symbol could not be resolved or if
        the library could not be loaded.

        **See also** **resolve** ().
        """
        ...

    def loadHints(self) -> "QLibrary.LoadHint":
        """
        https://doc.qt.io/qt-6/qlibrary.html#loadHints-prop

        **loadHints : LoadHints**

        Give the **load** () function some hints on how it should behave.

        You can give some hints on how the symbols are resolved. Usually, the
        symbols are not resolved at load time, but resolved lazily, (that is,
        when **resolve** () is called). If you set the loadHints to
        **ResolveAllSymbolsHint** , then all symbols will be resolved at load
        time if the platform supports it.

        Setting **ExportExternalSymbolsHint**  will make the external symbols in
        the library available for resolution in subsequent loaded libraries.

        If **LoadArchiveMemberHint**  is set, the file name is composed of two
        components: A path which is a reference to an archive file followed by
        the second component which is the reference to the archive member. For
        instance, the **fileName**  `libGL.a(shr_64.o)` will refer to the
        library `shr_64.o` in the archive file named `libGL.a`. This is only
        supported on the AIX platform.

        The interpretation of the load hints is platform dependent, and if you
        use it you are probably making some assumptions on which platform you
        are compiling for, so use them only if you understand the consequences
        of them.

        By default, none of these flags are set, so libraries will be loaded
        with lazy symbol resolution, and will not export external symbols for
        resolution in other dynamically-loaded libraries.

        **Note:** Setting this property after the library has been loaded has no
        effect and loadHints() will not reflect those changes.

        **Note:** This property is shared among all **QLibrary**  instances that
        refer to the same library.

        **Access functions:**

        QLibrary::LoadHints **loadHints** () const
        void **setLoadHints**
        (QLibrary::LoadHints **hints** )

        **Member Function Documentation**
        """
        ...

    def load(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlibrary.html#load

        **bool QLibrary::load()**

        Loads the library and returns `true` if the library was loaded
        successfully; otherwise returns `false`. Since **resolve** () always
        calls this function before resolving any symbols it is not necessary to
        call it explicitly. In some situations you might want the library loaded
        in advance, in which case you would use this function.

        **See also** **unload** ().
        """
        ...

    def isLoaded(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlibrary.html#isLoaded

        **bool QLibrary::isLoaded() const**

        Returns `true` if the library is loaded; otherwise returns `false`.

        **See also** **load** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlibrary.html#fileName-prop

        **fileName : QString**

        This property holds the file name of the library

        We recommend omitting the file's suffix in the file name, since
        **QLibrary**  will automatically look for the file with the appropriate
        suffix (see **isLibrary** ()).

        When loading the library, **QLibrary**  searches in all system-specific
        library locations (for example, `LD_LIBRARY_PATH` on Unix), unless the
        file name has an absolute path. After loading the library successfully,
        fileName() returns the fully-qualified file name of the library,
        including the full path to the library if one was given in the
        constructor or passed to setFileName().

        For example, after successfully loading the "GL" library on Unix
        platforms, fileName() will return "libGL.so". If the file name was
        originally passed as "/usr/lib/libGL", fileName() will return
        "/usr/lib/libGL.so".

        **Access functions:**

        QString **fileName** () const
        void **setFileName** (const QString &
        **fileName** )
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qlibrary.html#errorString

        **QString QLibrary::errorString() const**

        Returns a text string with the description of the last error that
        occurred. Currently, errorString will only be set if **load** (),
        **unload** () or **resolve** () for some reason fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtCore import *
import enum

PYQT_SIGNAL = typing.Union[pyqtSignal, pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], pyqtBoundSignal]
PYQT_VERSION: int = ...
PYQT_VERSION_STR: str = ...
QT_VERSION: int = ...
QT_VERSION_STR: str = ...


def qSetRealNumberPrecision(precision: int) -> QTextStreamManipulator:
    ...


def qSetPadChar(ch: str) -> QTextStreamManipulator:
    ...


def qSetFieldWidth(width: int) -> QTextStreamManipulator:
    ...


def Q_RETURN_ARG(type: typing.Any) -> QGenericReturnArgument:
    ...


def Q_ARG(type: typing.Any, data: typing.Any) -> QGenericArgument:
    ...


def QT_TRANSLATE_NOOP(a0: str, a1: str) -> str:
    ...


def QT_TR_NOOP(a0: str) -> str:
    ...


def pyqtSlot(
    *types, name: typing.Optional[str] = ..., result: typing.Optional[str] = ...
) -> typing.Any:
    ...


def pyqtEnum(a0: enum.Enum = ...) -> None:
    ...


def pyqtClassInfo(a0: str, a1: str) -> None:
    ...


def qFloatDistance(a: float, b: float) -> int:
    ...


def qQNaN() -> float:
    ...


def qSNaN() -> float:
    ...


def qInf() -> float:
    ...


def qIsNaN(d: float) -> bool:
    ...


def qIsFinite(d: float) -> bool:
    ...


def qIsInf(d: float) -> bool:
    ...


def qFormatLogMessage(type: QtMsgType, context: QMessageLogContext, buf: str) -> str:
    ...


def qSetMessagePattern(messagePattern: str) -> None:
    ...


def qInstallMessageHandler(
    a0: typing.Optional[typing.Callable[[QtMsgType, QMessageLogContext, str], None]]
) -> typing.Optional[typing.Callable[[QtMsgType, QMessageLogContext, str], None]]:
    ...


def qWarning(msg: str) -> None:
    ...


def qInfo(msg: str) -> None:
    ...


def qFatal(msg: str) -> None:
    ...


def qDebug(msg: str) -> None:
    ...


def qCritical(msg: str) -> None:
    ...


def pyqtRestoreInputHook() -> None:
    ...


def pyqtRemoveInputHook() -> None:
    ...


def qAddPreRoutine(routine: typing.Callable[[], None]) -> None:
    ...


def qRemovePostRoutine(a0: typing.Callable[..., None]) -> None:
    ...


def qAddPostRoutine(a0: typing.Callable[..., None]) -> None:
    ...


def qChecksum(
    data: typing.Union[QByteArray, bytes, bytearray, memoryview],
    standard: Qt.ChecksumType = ...,
) -> int:
    ...


@typing.overload
def qUncompress(data: bytes) -> QByteArray:
    ...


@typing.overload
def qUncompress(data: QByteArray) -> QByteArray:
    ...


@typing.overload
def qCompress(data: bytes, compressionLevel: int = ...) -> QByteArray:
    ...


@typing.overload
def qCompress(data: QByteArray, compressionLevel: int = ...) -> QByteArray:
    ...


def qEnvironmentVariableIntValue(varName: str) -> typing.Tuple[int, bool]:
    ...


@typing.overload
def qEnvironmentVariable(varName: str) -> str:
    ...


@typing.overload
def qEnvironmentVariable(varName: str, defaultValue: str) -> str:
    ...


def qEnvironmentVariableIsSet(varName: str) -> bool:
    ...


def qEnvironmentVariableIsEmpty(varName: str) -> bool:
    ...


def pyqtPickleProtocol() -> typing.Optional[int]:
    ...


def pyqtSetPickleProtocol(a0: typing.Optional[int]) -> None:
    ...


def qFuzzyCompare(p1: float, p2: float) -> bool:
    ...


def qVersion() -> str:
    ...


def qRound64(d: float) -> int:
    ...


def qRound(d: float) -> int:
    ...


def qAbs(t: float) -> float:
    ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QTextBlockUserData(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qtextblockuserdata.html

    **Detailed Description**

    QTextBlockUserData provides an abstract interface for container classes that
    are used to associate application-specific user data with text blocks in a
    **QTextDocument** .

    Generally, subclasses of this class provide functions to allow data to be
    stored and retrieved, and instances are attached to blocks of text using
    **QTextBlock::setUserData** (). This makes it possible to store additional
    data per text block in a way that can be retrieved safely by the
    application.

    Each subclass should provide a reimplementation of the destructor to ensure
    that any private data is automatically cleaned up when user data objects are
    deleted.

    **See also** **QTextBlock** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QTextBlockUserData") -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QMessageLogContext(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmessagelogcontext.html

    **Detailed Description**

    The class provides information about the source code location a **qDebug**
    (), **qInfo** (), **qWarning** (), **qCritical** () or **qFatal** () message
    was generated.

    **Note:** By default, this information is recorded only in debug builds. You
    can overwrite this explicitly by defining `QT_MESSAGELOGCONTEXT` or
    `QT_NO_MESSAGELOGCONTEXT`.

    **See also** **QMessageLogger** , **QtMessageHandler** , and
    **qInstallMessageHandler** ().
    """

    category: str = ...
    file: str = ...
    function: str = ...
    line: int = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore


class QFileIconProvider(QtGui.QAbstractFileIconProvider):
    """
    https://doc.qt.io/qt-6/qfileiconprovider.html

    **Detailed Description**
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qfileiconprovider.html#QFileIconProvider

        **QFileIconProvider::QFileIconProvider()**

        Constructs a file icon provider.
        """
        ...

    @typing.overload
    def icon(self, type: QtGui.QAbstractFileIconProvider.IconType) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qfileiconprovider.html#icon

        **[override virtual] QIcon
        QFileIconProvider::icon(QAbstractFileIconProvider::IconType type )
        const**

        Reimplements:
        **QAbstractFileIconProvider::icon(QAbstractFileIconProvider::IconType
        type) const** .
        """
        ...

    @typing.overload
    def icon(self, info: QtCore.QFileInfo) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qfileiconprovider.html#icon-1

        **[override virtual] QIcon QFileIconProvider::icon(const QFileInfo &
        info ) const**

        Reimplements: **QAbstractFileIconProvider::icon(const QFileInfo &info)
        const** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtNetwork
from PyQt6 import QtCore
from PyQt6.QtWebSockets import *


class QWebSocket(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qwebsocket.html

    **Detailed Description**

    WebSockets is a web technology providing full-duplex communications channels
    over a single TCP connection. The WebSocket protocol was standardized by the
    IETF as **RFC 6455**  in 2011. QWebSocket can both be used in a client
    application and server application.

    This class was modeled after **QAbstractSocket** .

    QWebSocket currently does not support **WebSocket Extensions**  and
    **WebSocket Subprotocols** .

    QWebSocket only supports version 13 of the WebSocket protocol, as outlined
    in **RFC 6455** .

    **Note:** Some proxies do not understand certain HTTP headers used during a
    WebSocket handshake. In that case, non-secure WebSocket connections fail.
    The best way to mitigate against this problem is to use WebSocket over a
    secure connection.

    **Warning:** To generate masks, this implementation of WebSockets uses the
    reasonably secure **QRandomGenerator::global** ()->generate() function. For
    more information about the importance of good masking, see **"Talking to
    Yourself for Fun and Profit" by Lin-Shung Huang et al** . The best measure
    against attacks mentioned in the document above, is to use QWebSocket over a
    secure connection ( **wss://** ). In general, always be careful to not have
    3rd party script access to a QWebSocket in your application.

    **See also** **QAbstractSocket** , **QTcpSocket** , and **QWebSocket client
    example** .
    """

    def __init__(
        self,
        origin: str = ...,
        version: "QWebSocketProtocol.Version" = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#QWebSocket-1

        **QWebSocket::QWebSocket(const QString & origin = QString(),
        QWebSocketProtocol::Version version = QWebSocketProtocol::VersionLatest,
        QObject * parent = nullptr)**

        Creates a new QWebSocket with the given **origin** , the **version** of
        the protocol to use and **parent**.

        The **origin** of the client is as specified in **RFC 6454** . (The
        **origin** is not required for non-web browser clients (see **RFC 6455**
        )). The **origin** may not contain new line characters, otherwise the
        connection will be aborted immediately during the handshake phase.

        **Note:** Currently only V13 (**RFC 6455** ) is supported
        """
        ...

    def continueInterruptedHandshake(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#continueInterruptedHandshake

        **[since 6.2] void QWebSocket::continueInterruptedHandshake()**

        If an application wants to conclude a handshake even after receiving
        **handshakeInterruptedOnError** () signal, it must call this function.
        This call must be done from a slot function attached to the signal. The
        signal-slot connection must be direct.

        This function was introduced in Qt 6.2.

        **See also** **handshakeInterruptedOnError** () and
        **QSslConfiguration::setHandshakeMustInterruptOnError** ().
        """
        ...

    @staticmethod
    def maxOutgoingFrameSize() -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#maxOutgoingFrameSize

        **[static, since 5.15] quint64 QWebSocket::maxOutgoingFrameSize()**

        Returns the maximum supported size of an outgoing websocket frame for
        this websocket implementation.

        This function was introduced in Qt 5.15.
        """
        ...

    def outgoingFrameSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#outgoingFrameSize

        **[since 5.15] quint64 QWebSocket::outgoingFrameSize() const**

        Returns the maximum size of an outgoing websocket frame.

        This function was introduced in Qt 5.15.

        **See also** **setOutgoingFrameSize** ().
        """
        ...

    def setOutgoingFrameSize(self, outgoingFrameSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setOutgoingFrameSize

        **[since 5.15] void QWebSocket::setOutgoingFrameSize(quint64
        outgoingFrameSize )**

        Sets the maximum size of an outgoing websocket frame to
        **outgoingFrameSize**. The accepted range is between 0 and
        **maxOutgoingFrameSize** (), default is 512kB. The purpose of this
        function is to adapt to the maximum allowed frame size of the receiver.

        This function was introduced in Qt 5.15.

        **See also** **outgoingFrameSize** ().
        """
        ...

    @staticmethod
    def maxIncomingFrameSize() -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#maxIncomingFrameSize

        **[static, since 5.15] quint64 QWebSocket::maxIncomingFrameSize()**

        Returns the maximum supported size of an incoming websocket frame for
        this websocket implementation.

        This function was introduced in Qt 5.15.
        """
        ...

    @staticmethod
    def maxIncomingMessageSize() -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#maxIncomingMessageSize

        **[static, since 5.15] quint64 QWebSocket::maxIncomingMessageSize()**

        Returns the maximum supported size of an incoming websocket message for
        this websocket implementation.

        This function was introduced in Qt 5.15.
        """
        ...

    def maxAllowedIncomingMessageSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#maxAllowedIncomingMessageSize

        **[since 5.15] quint64 QWebSocket::maxAllowedIncomingMessageSize()
        const**

        Returns the maximum allowed size of an incoming websocket message.

        This function was introduced in Qt 5.15.

        **See also** **setMaxAllowedIncomingMessageSize** ().
        """
        ...

    def setMaxAllowedIncomingMessageSize(
        self, maxAllowedIncomingMessageSize: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setMaxAllowedIncomingMessageSize

        **[since 5.15] void QWebSocket::setMaxAllowedIncomingMessageSize(quint64
        maxAllowedIncomingMessageSize )**

        Sets the maximum allowed size of an incoming websocket message to
        **maxAllowedIncomingMessageSize**. If an incoming message exceeds this
        limit, the peer gets disconnected. The accepted range is between 0 and
        **maxIncomingMessageSize** (), default is **maxIncomingMessageSize** ().
        The purpose of this function is to avoid exhausting virtual memory.

        This function was introduced in Qt 5.15.

        **See also** **maxAllowedIncomingMessageSize** ().
        """
        ...

    def maxAllowedIncomingFrameSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#maxAllowedIncomingFrameSize

        **[since 5.15] quint64 QWebSocket::maxAllowedIncomingFrameSize() const**

        Returns the maximum allowed size of an incoming websocket frame.

        This function was introduced in Qt 5.15.

        **See also** **setMaxAllowedIncomingFrameSize** ().
        """
        ...

    def setMaxAllowedIncomingFrameSize(self, maxAllowedIncomingFrameSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setMaxAllowedIncomingFrameSize

        **[since 5.15] void QWebSocket::setMaxAllowedIncomingFrameSize(quint64
        maxAllowedIncomingFrameSize )**

        Sets the maximum allowed size of an incoming websocket frame to
        **maxAllowedIncomingFrameSize**. If an incoming frame exceeds this
        limit, the peer gets disconnected. The accepted range is between 0 and
        **maxIncomingFrameSize** (), default is **maxIncomingFrameSize** (). The
        purpose of this function is to avoid exhausting virtual memory.

        This function was introduced in Qt 5.15.

        **See also** **maxAllowedIncomingFrameSize** ().
        """
        ...

    def bytesToWrite(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#bytesToWrite

        **[since 5.12] qint64 QWebSocket::bytesToWrite() const**

        Returns the number of bytes that are waiting to be written. The bytes
        are written when control goes back to the event loop or when **flush**
        () is called.

        This function was introduced in Qt 5.12.

        **See also** **flush** .
        """
        ...

    def ping(self, payload: QtCore.QByteArray = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#ping

        **[slot] void QWebSocket::ping(const QByteArray & payload =
        QByteArray())**

        Pings the server to indicate that the connection is still alive.
        Additional **payload** can be sent along the ping message.

        The size of the **payload** cannot be bigger than 125. If it is larger,
        the **payload** is clipped to 125 bytes.

        **Note:****QWebSocket**  and **QWebSocketServer**  handles ping requests
        internally, which means they automatically send back a pong response to
        the peer.

        **See also** **pong** ().
        """
        ...

    @typing.overload
    def open(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#open

        **[slot] void QWebSocket::open(const QUrl & url )**

        Opens a WebSocket connection using the given **url**.

        If the url contains newline characters (\\r\\n), then the error signal
        will be emitted with **QAbstractSocket::ConnectionRefusedError**  as
        error type.
        """
        ...

    @typing.overload
    def open(self, request: QtNetwork.QNetworkRequest) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#open-1

        **[slot, since 5.6] void QWebSocket::open(const QNetworkRequest &
        request )**

        Opens a WebSocket connection using the given **request**.

        The **request** url will be used to open the WebSocket connection.
        Headers present in the request will be sent to the server in the upgrade
        request, together with the ones needed for the websocket handshake.

        This function was introduced in Qt 5.6.
        """
        ...

    def close(
        self, closeCode: "QWebSocketProtocol.CloseCode" = ..., reason: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#close

        **[slot] void QWebSocket::close(QWebSocketProtocol::CloseCode closeCode
        = QWebSocketProtocol::CloseCodeNormal, const QString & reason =
        QString())**

        Gracefully closes the socket with the given **closeCode** and
        **reason**.

        Any data in the write buffer is flushed before the socket is closed. The
        **closeCode** is a **QWebSocketProtocol::CloseCode**  indicating the
        reason to close, and **reason** describes the reason of the closure more
        in detail. All control frames, including the Close frame, are limited to
        125 bytes. Since two of these are used for **closeCode** the maximum
        length of **reason** is 123! If **reason** exceeds this limit it will be
        truncated.
        """
        ...

    def request(self) -> QtNetwork.QNetworkRequest:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#request

        **[since 5.6] QNetworkRequest QWebSocket::request() const**

        Returns the request that was or will be used to open this socket.

        This function was introduced in Qt 5.6.
        """
        ...

    def sslConfiguration(self) -> QtNetwork.QSslConfiguration:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#sslConfiguration

        **QSslConfiguration QWebSocket::sslConfiguration() const**

        Returns the socket's SSL configuration state. The default SSL
        configuration of a socket is to use the default ciphers, default CA
        certificates, no local private key or certificate. The SSL configuration
        also contains fields that can change with time without notice.

        **See also** **setSslConfiguration** ().
        """
        ...

    def setSslConfiguration(
        self, sslConfiguration: QtNetwork.QSslConfiguration
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setSslConfiguration

        **void QWebSocket::setSslConfiguration(const QSslConfiguration &
        sslConfiguration )**

        Sets the socket's SSL configuration to be the contents of
        **sslConfiguration**.

        This function sets the local certificate, the ciphers, the private key
        and the CA certificates to those stored in **sslConfiguration**. It is
        not possible to set the SSL-state related fields.

        **See also** **sslConfiguration** ().
        """
        ...

    @typing.overload
    def ignoreSslErrors(self, errors: typing.Iterable[QtNetwork.QSslError]) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#ignoreSslErrors

        **[slot] void QWebSocket::ignoreSslErrors()**

        This slot tells **QWebSocket**  to ignore errors during **QWebSocket**
        's handshake phase and continue connecting. If you want to continue with
        the connection even if errors occur during the handshake phase, then you
        must call this slot, either from a slot connected to **sslErrors** (),
        or before the handshake phase. If you don't call this slot, either in
        response to errors or before the handshake, the connection will be
        dropped after the **sslErrors** () signal has been emitted.

        **Warning:** Be sure to always let the user inspect the errors reported
        by the **sslErrors** () signal, and only call this method upon
        confirmation from the user that proceeding is ok. If there are
        unexpected errors, the connection should be aborted. Calling this method
        without inspecting the actual errors will most likely pose a security
        risk for your application. Use it with great care!

        **See also** **sslErrors** (), **QSslSocket::ignoreSslErrors** (), and
        **QNetworkReply::ignoreSslErrors** ().
        """
        ...

    @typing.overload
    def ignoreSslErrors(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#ignoreSslErrors-1

        **void QWebSocket::ignoreSslErrors(const QList<QSslError> & errors )**

        This is an overloaded function.

        This method tells **QWebSocket**  to ignore the errors given in
        **errors**.

        Note that you can set the expected certificate in the SSL error: If, for
        instance, you want to connect to a server that uses a self-signed
        certificate, consider the following snippet:

        **QList** <**QSslCertificate** > cert = **QSslCertificate**
        ::fromPath(QLatin1String("server-certificate.pem"));
            **QSslError**
        error(**QSslError** ::SelfSignedCertificate, cert.at(0));
            **QList**
        <**QSslError** > expectedSslErrors;
            expectedSslErrors.append(error);
        QWebSocket socket;
            socket.ignoreSslErrors(expectedSslErrors);
        socket.open(**QUrl** (**QStringLiteral** ("wss://myserver.at.home")));

        Multiple calls to this function will replace the list of errors that
        were passed in previous calls. You can clear the list of errors you want
        to ignore by calling this function with an empty list.

        **See also** **sslErrors** ().
        """
        ...

    def sendBinaryMessage(self, data: QtCore.QByteArray) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#sendBinaryMessage

        **qint64 QWebSocket::sendBinaryMessage(const QByteArray & data )**

        Sends the given **data** over the socket as a binary message and returns
        the number of bytes actually sent.

        **See also** **sendTextMessage** ().
        """
        ...

    def sendTextMessage(self, message: str) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#sendTextMessage

        **qint64 QWebSocket::sendTextMessage(const QString & message )**

        Sends the given **message** over the socket as a text message and
        returns the number of bytes actually sent.

        **See also** **sendBinaryMessage** ().
        """
        ...

    def closeReason(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#closeReason

        **QString QWebSocket::closeReason() const**

        Returns the reason why the socket was closed.

        **See also** **closeCode** ().
        """
        ...

    def closeCode(self) -> "QWebSocketProtocol.CloseCode":
        """
        https://doc.qt.io/qt-6/qwebsocket.html#closeCode

        **QWebSocketProtocol::CloseCode QWebSocket::closeCode() const**

        Returns the code indicating why the socket was closed.

        **See also** **QWebSocketProtocol::CloseCode**  and **closeReason** ().
        """
        ...

    def origin(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#origin

        **QString QWebSocket::origin() const**

        Returns the current origin.
        """
        ...

    def requestUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#requestUrl

        **QUrl QWebSocket::requestUrl() const**

        Returns the url the socket is connected to or will connect to.
        """
        ...

    def resourceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#resourceName

        **QString QWebSocket::resourceName() const**

        Returns the name of the resource currently accessed.
        """
        ...

    def version(self) -> "QWebSocketProtocol.Version":
        """
        https://doc.qt.io/qt-6/qwebsocket.html#version

        **QWebSocketProtocol::Version QWebSocket::version() const**

        Returns the version the socket is currently using.
        """
        ...

    def state(self) -> QtNetwork.QAbstractSocket.SocketState:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#state

        **QAbstractSocket::SocketState QWebSocket::state() const**

        Returns the current state of the socket.
        """
        ...

    def setPauseMode(self, pauseMode: QtNetwork.QAbstractSocket.PauseMode) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setPauseMode

        **void QWebSocket::setPauseMode(QAbstractSocket::PauseModes pauseMode
        )**

        Controls whether to pause upon receiving a notification. The
        **pauseMode** parameter specifies the conditions in which the socket
        should be paused.

        The only notification currently supported is **sslErrors** (). If set to
        PauseOnSslErrors, data transfer on the socket will be paused and needs
        to be enabled explicitly again by calling **resume** (). By default,
        this option is set to PauseNever. This option must be called before
        connecting to the server, otherwise it will result in undefined
        behavior.

        **See also** **pauseMode** () and **resume** ().
        """
        ...

    def resume(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#resume

        **void QWebSocket::resume()**

        Continues data transfer on the socket. This method should only be used
        after the socket has been set to pause upon notifications and a
        notification has been received. The only notification currently
        supported is **sslErrors** (). Calling this method if the socket is not
        paused results in undefined behavior.

        **See also** **pauseMode** () and **setPauseMode** ().
        """
        ...

    def setReadBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setReadBufferSize

        **void QWebSocket::setReadBufferSize(qint64 size )**

        Sets the size of **QWebSocket** 's internal read buffer to be **size**
        bytes.

        If the buffer size is limited to a certain size, **QWebSocket**  won't
        buffer more than this size of data. Exceptionally, a buffer size of 0
        means that the read buffer is unlimited and all incoming data is
        buffered. This is the default. This option is useful if you only read
        the data at certain points in time (for example, in a real-time
        streaming application) or if you want to protect your socket against
        receiving too much data, which may eventually cause your application to
        run out of memory.

        **See also** **readBufferSize** ().
        """
        ...

    def readBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#readBufferSize

        **qint64 QWebSocket::readBufferSize() const**

        Returns the size in bytes of the readbuffer that is used by the socket.

        **See also** **setReadBufferSize** ().
        """
        ...

    def maskGenerator(self) -> QMaskGenerator:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#maskGenerator

        **const QMaskGenerator *QWebSocket::maskGenerator() const**

        Returns the mask generator that is currently used by this **QWebSocket**
        .

        **See also** **setMaskGenerator** ().
        """
        ...

    def setMaskGenerator(self, maskGenerator: QMaskGenerator) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setMaskGenerator

        **void QWebSocket::setMaskGenerator(const QMaskGenerator * maskGenerator
        )**

        Sets the generator to use for creating masks to **maskGenerator**. The
        default **QWebSocket**  generator can be reset by supplying a
        **nullptr**. The mask generator can be changed at any time, even while
        the connection is open.

        **See also** **maskGenerator** ().
        """
        ...

    def setProxy(self, networkProxy: QtNetwork.QNetworkProxy) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#setProxy

        **void QWebSocket::setProxy(const QNetworkProxy & networkProxy )**

        Sets the proxy to **networkProxy**

        **See also** **proxy** ().
        """
        ...

    def proxy(self) -> QtNetwork.QNetworkProxy:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#proxy

        **QNetworkProxy QWebSocket::proxy() const**

        Returns the currently configured proxy

        **See also** **setProxy** ().
        """
        ...

    def peerPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#peerPort

        **quint16 QWebSocket::peerPort() const**

        Returns the peerport
        """
        ...

    def peerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#peerName

        **QString QWebSocket::peerName() const**

        Returns the peerName
        """
        ...

    def peerAddress(self) -> QtNetwork.QHostAddress:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#peerAddress

        **QHostAddress QWebSocket::peerAddress() const**

        Returns the peer address
        """
        ...

    def pauseMode(self) -> QtNetwork.QAbstractSocket.PauseMode:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#pauseMode

        **QAbstractSocket::PauseModes QWebSocket::pauseMode() const**

        Returns the pause mode of this socket

        **See also** **setPauseMode** ().
        """
        ...

    def localPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#localPort

        **quint16 QWebSocket::localPort() const**

        Returns the local port
        """
        ...

    def localAddress(self) -> QtNetwork.QHostAddress:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#localAddress

        **QHostAddress QWebSocket::localAddress() const**

        Returns the local address
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#isValid

        **bool QWebSocket::isValid() const**

        Returns `true` if the socket is ready for reading and writing; otherwise
        returns `false`.
        """
        ...

    def flush(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#flush

        **bool QWebSocket::flush()**

        This function writes as much as possible from the internal write buffer
        to the underlying network socket, without blocking. If any data was
        written, this function returns true; otherwise false is returned. Call
        this function if you need **QWebSocket**  to start sending buffered data
        immediately. The number of bytes successfully written depends on the
        operating system. In most cases, you do not need to call this function,
        because **QWebSocket**  will start sending data automatically once
        control goes back to the event loop.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#errorString

        **QString QWebSocket::errorString() const**

        Returns a human-readable description of the last error that occurred

        **See also** **error** ().
        """
        ...

    def abort(self) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#abort

        **void QWebSocket::abort()**

        Aborts the current socket and resets the socket. Unlike **close** (),
        this function immediately closes the socket, discarding any pending data
        in the write buffer.
        """
        ...

    @property
    def aboutToClose(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#aboutToClose

        **[signal] void QWebSocket::aboutToClose()**

        This signal is emitted when the socket is about to close. Connect this
        signal if you have operations that need to be performed before the
        socket closes (e.g., if you have data in a separate buffer that needs to
        be written to the device).

        **See also** **close** ().
        """
        ...

    @property
    def alertReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#alertReceived

        **[signal, since 6.2] void QWebSocket::alertReceived(QSsl::AlertLevel
        level , QSsl::AlertType type , const QString & description )**

        **QWebSocket**  emits this signal if an alert message was received from
        a peer. **level** tells if the alert was fatal or it was a warning.
        **type** is the code explaining why the alert was sent. When a textual
        description of the alert message is available, it is supplied in
        **description**.

        **Note:** The signal is mostly for informational and debugging purposes
        and does not require any handling in the application. If the alert was
        fatal, underlying backend will handle it and close the connection.

        **Note:** Not all backends support this functionality.

        This function was introduced in Qt 6.2.

        **See also** **alertSent** (), **QSsl::AlertLevel** , and
        **QSsl::AlertType** .
        """
        ...

    @property
    def alertSent(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#alertSent

        **[signal, since 6.2] void QWebSocket::alertSent(QSsl::AlertLevel level
        , QSsl::AlertType type , const QString & description )**

        **QWebSocket**  emits this signal if an alert message was sent to a
        peer. **level** describes if it was a warning or a fatal error. **type**
        gives the code of the alert message. When a textual description of the
        alert message is available, it is supplied in **description**.

        **Note:** This signal is mostly informational and can be used for
        debugging purposes, normally it does not require any actions from the
        application.

        **Note:** Not all backends support this functionality.

        This function was introduced in Qt 6.2.

        **See also** **alertReceived** (), **QSsl::AlertLevel** , and
        **QSsl::AlertType** .
        """
        ...

    @property
    def binaryFrameReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#binaryFrameReceived

        **[signal] void QWebSocket::binaryFrameReceived(const QByteArray & frame
        , bool isLastFrame )**

        This signal is emitted whenever a binary frame is received. The
        **frame** contains the data and **isLastFrame** indicates whether this
        is the last frame of the complete message.

        This signal can be used to process large messages frame by frame,
        instead of waiting for the complete message to arrive.

        **See also** **textFrameReceived** ().
        """
        ...

    @property
    def binaryMessageReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#binaryMessageReceived

        **[signal] void QWebSocket::binaryMessageReceived(const QByteArray &
        message )**

        This signal is emitted whenever a binary message is received. The
        **message** contains the received bytes.

        **See also** **textMessageReceived** ().
        """
        ...

    @property
    def bytesWritten(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#bytesWritten

        **[signal] void QWebSocket::bytesWritten(qint64 bytes )**

        This signal is emitted every time a payload of data has been written to
        the socket. The **bytes** argument is set to the number of bytes that
        were written in this payload.

        **Note:** This signal has the same meaning both for secure and non-
        secure WebSockets. As opposed to **QSslSocket** , bytesWritten() is only
        emitted when encrypted data is effectively written (see
        **QSslSocket::encryptedBytesWritten** ()).

        **See also** **close** ().
        """
        ...

    @property
    def connected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#connected

        **[signal] void QWebSocket::connected()**

        Emitted when a connection is successfully established. A connection is
        successfully established when the socket is connected and the handshake
        was successful.

        **See also** **open** () and **disconnected** ().
        """
        ...

    @property
    def disconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#disconnected

        **[signal] void QWebSocket::disconnected()**

        Emitted when the socket is disconnected.

        **See also** **close** () and **connected** ().
        """
        ...

    @property
    def error(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#error

        **QAbstractSocket::SocketError QWebSocket::error() const**

        Returns the type of error that last occurred

        **See also** **errorString** ().
        """
        ...

    @property
    def handshakeInterruptedOnError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#handshakeInterruptedOnError

        **[signal, since 6.2] void QWebSocket::handshakeInterruptedOnError(const
        QSslError & error )**

        **QWebSocket**  emits this signal if a certificate verification error
        was found and if early error reporting was enabled in
        **QSslConfiguration** . An application is expected to inspect the
        **error** and decide if it wants to continue the handshake, or abort it
        and send an alert message to the peer. The signal-slot connection must
        be direct.

        This function was introduced in Qt 6.2.

        **See also** **continueInterruptedHandshake** (), **sslErrors** (), and
        **QSslConfiguration::setHandshakeMustInterruptOnError** ().
        """
        ...

    @property
    def peerVerifyError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#peerVerifyError

        **[signal, since 6.2] void QWebSocket::peerVerifyError(const QSslError &
        error )**

        **QWebSocket**  can emit this signal several times during the SSL
        handshake, before encryption has been established, to indicate that an
        error has occurred while establishing the identity of the peer. The
        **error** is usually an indication that **QWebSocket**  is unable to
        securely identify the peer.

        This signal provides you with an early indication when something's
        wrong. By connecting to this signal, you can manually choose to tear
        down the connection from inside the connected slot before the handshake
        has completed. If no action is taken, **QWebSocket**  will proceed to
        emitting **QWebSocket::sslErrors** ().

        This function was introduced in Qt 6.2.

        **See also** **sslErrors** ().
        """
        ...

    @property
    def pong(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#pong

        **[signal] void QWebSocket::pong(quint64 elapsedTime , const QByteArray
        & payload )**

        Emitted when a pong message is received in reply to a previous ping.
        **elapsedTime** contains the roundtrip time in milliseconds and
        **payload** contains an optional payload that was sent with the ping.

        **See also** **ping** ().
        """
        ...

    @property
    def preSharedKeyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#preSharedKeyAuthenticationRequire
        d

        **[signal, since 5.8] void QWebSocket::preSharedKeyAuthenticationRequire
        d(QSslPreSharedKeyAuthenticator * authenticator )**

        This signal is emitted if the SSL/TLS handshake negotiates a PSK
        ciphersuite, and therefore a PSK authentication is then required.

        When using PSK, the client must send to the server a valid identity and
        a valid pre shared key, in order for the SSL handshake to continue.
        Applications can provide this information in a slot connected to this
        signal, by filling in the passed **authenticator** object according to
        their needs.

        **Note:** Ignoring this signal, or failing to provide the required
        credentials, will cause the handshake to fail, and therefore the
        connection to be aborted.

        **Note:** The **authenticator** object is owned by the websocket and
        must not be deleted by the application.

        This function was introduced in Qt 5.8.

        **See also** **QSslPreSharedKeyAuthenticator**  and
        **QSslSocket::preSharedKeyAuthenticationRequired** ().
        """
        ...

    @property
    def proxyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#proxyAuthenticationRequired

        **[signal] void QWebSocket::proxyAuthenticationRequired(const
        QNetworkProxy & proxy , QAuthenticator * authenticator )**

        This signal can be emitted when a **proxy** that requires authentication
        is used. The **authenticator** object can then be filled in with the
        required details to allow authentication and continue the connection.

        **Note:** It is not possible to use a QueuedConnection to connect to
        this signal, as the connection will fail if the authenticator has not
        been filled in with new information when the signal returns.

        **See also** **QAuthenticator**  and **QNetworkProxy** .
        """
        ...

    @property
    def readChannelFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#readChannelFinished

        **[signal] void QWebSocket::readChannelFinished()**

        This signal is emitted when the input (reading) stream is closed in this
        device. It is emitted as soon as the closing is detected.

        **See also** **close** ().
        """
        ...

    @property
    def sslErrors(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#sslErrors

        **[signal] void QWebSocket::sslErrors(const QList<QSslError> & errors
        )**

        **QWebSocket**  emits this signal after the SSL handshake to indicate
        that one or more errors have occurred while establishing the identity of
        the peer. The errors are usually an indication that **QWebSocket**  is
        unable to securely identify the peer. Unless any action is taken, the
        connection will be dropped after this signal has been emitted. If you
        want to continue connecting despite the errors that have occurred, you
        must call **QWebSocket::ignoreSslErrors** () from inside a slot
        connected to this signal. If you need to access the error list at a
        later point, you can call sslErrors() (without arguments).

        **errors** contains one or more errors that prevent **QWebSocket**  from
        verifying the identity of the peer.

        **Note:** You cannot use **Qt::QueuedConnection**  when connecting to
        this signal, or calling **QWebSocket::ignoreSslErrors** () will have no
        effect.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#stateChanged

        **[signal] void QWebSocket::stateChanged(QAbstractSocket::SocketState
        state )**

        This signal is emitted whenever **QWebSocket** 's state changes. The
        **state** parameter is the new state.

        **Note:****QAbstractSocket::ConnectedState**  is emitted after the
        handshake with the server has succeeded.

        **QAbstractSocket::SocketState**  is not a registered metatype, so for
        queued connections, you will have to register it with
        Q_REGISTER_METATYPE() and **qRegisterMetaType** ().

        **See also** **state** ().
        """
        ...

    @property
    def textFrameReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#textFrameReceived

        **[signal] void QWebSocket::textFrameReceived(const QString & frame ,
        bool isLastFrame )**

        This signal is emitted whenever a text frame is received. The **frame**
        contains the data and **isLastFrame** indicates whether this is the last
        frame of the complete message.

        This signal can be used to process large messages frame by frame,
        instead of waiting for the complete message to arrive.

        **See also** **binaryFrameReceived** ().
        """
        ...

    @property
    def textMessageReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebsocket.html#textMessageReceived

        **[signal] void QWebSocket::textMessageReceived(const QString & message
        )**

        This signal is emitted whenever a text message is received. The
        **message** contains the received text.

        **See also** **binaryMessageReceived** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QTextFrame(QTextObject):
    """
    https://doc.qt.io/qt-6/qtextframe.html

    **Detailed Description**

    Text frames provide structure for the text in a document. They are used as
    generic containers for other document elements. Frames are usually created
    by using **QTextCursor::insertFrame** ().

    Frames can be used to create hierarchical structures in rich text documents.
    Each document has a root frame (**QTextDocument::rootFrame** ()), and each
    frame beneath the root frame has a parent frame and a (possibly empty) list
    of child frames. The parent frame can be found with **parentFrame** (), and
    the **childFrames** () function provides a list of child frames.

    Each frame contains at least one text block to enable text cursors to insert
    new document elements within. As a result, the **QTextFrame::iterator**
    class is used to traverse both the blocks and child frames within a given
    frame. The first and last child elements in the frame can be found with
    **begin** () and **end** ().

    A frame also has a format (specified using **QTextFrameFormat** ) which can
    be set with **setFormat** () and read with **format** ().

    Text cursors can be obtained that point to the first and last valid cursor
    positions within a frame; use the **firstCursorPosition** () and
    **lastCursorPosition** () functions for this. The frame's extent in the
    document can be found with **firstPosition** () and **lastPosition** ().

    You can iterate over a frame's contents using the **QTextFrame::iterator**
    class: this provides read-only access to its internal list of text blocks
    and child frames.

    **See also** **QTextCursor**  and **QTextDocument** .
    """

    class iterator(PyQt6.sip.simplewrapper):
        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QTextFrame.iterator") -> None:
            ...

        def atEnd(self) -> bool:
            ...

        def currentBlock(self) -> "QTextBlock":
            ...

        def currentFrame(self) -> "QTextFrame":
            ...

        def parentFrame(self) -> "QTextFrame":
            ...

    def __init__(self, doc: QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qtextframe.html#QTextFrame

        **QTextFrame::QTextFrame(QTextDocument * document )**

        Creates a new empty frame for the text **document**.
        """
        ...

    def setFrameFormat(self, aformat: QTextFrameFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtextframe.html#setFrameFormat

        **void QTextFrame::setFrameFormat(const QTextFrameFormat & format )**

        Sets the frame's **format**.

        **See also** **frameFormat** ().
        """
        ...

    def end(self) -> "QTextFrame.iterator":
        """
        https://doc.qt.io/qt-6/qtextframe.html#end

        **QTextFrame::iterator QTextFrame::end() const**

        Returns an iterator pointing to the position past the last document
        element inside the frame. Please see the document **STL-Style
        Iterators**  for more information.

        **See also** **begin** ().
        """
        ...

    def begin(self) -> "QTextFrame.iterator":
        """
        https://doc.qt.io/qt-6/qtextframe.html#begin

        **QTextFrame::iterator QTextFrame::begin() const**

        Returns an iterator pointing to the first document element inside the
        frame. Please see the document **STL-style-Iterators**  for more
        information.

        **See also** **end** ().
        """
        ...

    def parentFrame(self) -> "QTextFrame":
        """
        https://doc.qt.io/qt-6/qtextframe.html#parentFrame

        **QTextFrame *QTextFrame::parentFrame() const**

        Returns the frame's parent frame. If the frame is the root frame of a
        document, this will return 0.

        **See also** **childFrames** () and **QTextDocument::rootFrame** ().
        """
        ...

    def childFrames(self) -> typing.List["QTextFrame"]:
        """
        https://doc.qt.io/qt-6/qtextframe.html#childFrames

        **QList<QTextFrame *> QTextFrame::childFrames() const**

        Returns a (possibly empty) list of the frame's child frames.

        **See also** **parentFrame** ().
        """
        ...

    def lastPosition(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextframe.html#lastPosition

        **int QTextFrame::lastPosition() const**

        Returns the last document position inside the frame.

        **See also** **firstPosition** (), **firstCursorPosition** (), and
        **lastCursorPosition** ().
        """
        ...

    def firstPosition(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextframe.html#firstPosition

        **int QTextFrame::firstPosition() const**

        Returns the first document position inside the frame.

        **See also** **lastPosition** (), **firstCursorPosition** (), and
        **lastCursorPosition** ().
        """
        ...

    def lastCursorPosition(self) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextframe.html#lastCursorPosition

        **QTextCursor QTextFrame::lastCursorPosition() const**

        Returns the last cursor position inside the frame.

        **See also** **firstCursorPosition** (), **firstPosition** (), and
        **lastPosition** ().
        """
        ...

    def firstCursorPosition(self) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextframe.html#firstCursorPosition

        **QTextCursor QTextFrame::firstCursorPosition() const**

        Returns the first cursor position inside the frame.

        **See also** **lastCursorPosition** (), **firstPosition** (), and
        **lastPosition** ().
        """
        ...

    def frameFormat(self) -> QTextFrameFormat:
        """
        https://doc.qt.io/qt-6/qtextframe.html#frameFormat

        **QTextFrameFormat QTextFrame::frameFormat() const**

        Returns the frame's format.

        **See also** **setFrameFormat** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlApplicationEngine(QQmlEngine):
    """
    https://doc.qt.io/qt-6/qqmlapplicationengine.html

    **Detailed Description**

    This class combines a **QQmlEngine**  and **QQmlComponent**  to provide a
    convenient way to load a single QML file. It also exposes some central
    application functionality to QML, which a C++/QML hybrid application would
    normally control from C++.

    It can be used like so:

    #include <QGuiApplication>
        #include <QQmlApplicationEngine>

        int
    main(int argc, char *argv[])
        {
            **QGuiApplication**  app(argc,
    argv);
            **QQmlApplicationEngine**  engine("main.qml");
            return
    app.exec();
        }

    Unlike **QQuickView** , QQmlApplicationEngine does not automatically create
    a root window. If you are using visual items from Qt Quick, you will need to
    place them inside of a **Window** .

    You can also use **QCoreApplication**  with QQmlApplicationEngine, if you
    are not using any QML modules which require a **QGuiApplication**  (such as
    `QtQuick`).

    List of configuration changes from a default **QQmlEngine** :

    * Connecting Qt.**quit** () to **QCoreApplication::quit** ()
      *
    Automatically loads translation files from an i18n directory adjacent to the
    main QML file.
        * Translation files must have "qml_" prefix e.g.
    qml_ja_JP.qm.
      * Translations are reloaded when the `QJSEngine::uiLanguage`
    / `Qt.uiLanguage` property is changed.
      * Automatically sets an incubation
    controller if the scene contains a **QQuickWindow** .
      * Automatically sets
    a `QQmlFileSelector` as the url interceptor, applying file selectors to all
    QML files and assets.

    The engine behavior can be further tweaked by using the inherited methods
    from **QQmlEngine** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#QQmlApplicationEngine

        **QQmlApplicationEngine::QQmlApplicationEngine(QObject * parent =
        nullptr)**

        Create a new QQmlApplicationEngine with the given **parent**. You will
        have to call **load** () later in order to load a QML file.
        """
        ...

    @typing.overload
    def __init__(
        self, url: QtCore.QUrl, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#QQmlApplicationEngine-
        1

        **QQmlApplicationEngine::QQmlApplicationEngine(const QUrl & url ,
        QObject * parent = nullptr)**

        Create a new QQmlApplicationEngine and loads the QML file at the given
        **url**. This is provided as a convenience, and is the same as using the
        empty constructor and calling load afterwards.
        """
        ...

    @typing.overload
    def __init__(
        self, filePath: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#QQmlApplicationEngine-
        2

        **QQmlApplicationEngine::QQmlApplicationEngine(const QString & filePath
        , QObject * parent = nullptr)**

        Create a new QQmlApplicationEngine and loads the QML file at the given
        **filePath** , which must be a local file path. If a relative path is
        given then it will be interpreted as relative to the working directory
        of the application.

        This is provided as a convenience, and is the same as using the empty
        constructor and calling load afterwards.
        """
        ...

    def setInitialProperties(
        self, initialProperties: typing.Dict[str, typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#setInitialProperties

        **[slot, since 5.14] void
        QQmlApplicationEngine::setInitialProperties(const QVariantMap &
        initialProperties )**

        Sets the **initialProperties** with which the QML component gets
        initialized after it gets loaded.

        **QQmlApplicationEngine**  engine;

            EventDatabase eventDatabase;
        EventMonitor eventMonitor;

            engine.setInitialProperties({
        { "eventDatabase", **QVariant** ::fromValue(&eventDatabase) },
                {
        "eventMonitor", **QVariant** ::fromValue(&eventMonitor) }
            });

        This function was introduced in Qt 5.14.

        **See also** **QQmlComponent::setInitialProperties** ,
        **QQmlApplicationEngine::load** , and
        **QQmlApplicationEngine::loadData** .
        """
        ...

    def setExtraFileSelectors(self, extraFileSelectors: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#setExtraFileSelectors

        **[slot, since 6.0] void
        QQmlApplicationEngine::setExtraFileSelectors(const QStringList &
        extraFileSelectors )**

        Sets the **extraFileSelectors** to be passed to the internal
        **QQmlFileSelector**  used for resolving URLs to local files. The
        **extraFileSelectors** are applied when the first QML file is loaded.
        Setting them afterwards has no effect.

        This function was introduced in Qt 6.0.

        **See also** **QQmlFileSelector**  and
        **QFileSelector::setExtraSelectors** .
        """
        ...

    def loadData(self, data: QtCore.QByteArray, url: QtCore.QUrl = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#loadData

        **[slot] void QQmlApplicationEngine::loadData(const QByteArray & data ,
        const QUrl & url = QUrl())**

        Loads the QML given in **data**. The object tree defined by **data** is
        instantiated immediately.

        If a **url** is specified it is used as the base url of the component.
        This affects relative paths within the data and error messages.

        If an error occurs, error messages are printed with **qWarning** .
        """
        ...

    @typing.overload
    def load(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#load

        **[slot] void QQmlApplicationEngine::load(const QUrl & url )**

        Loads the root QML file located at **url**. The object tree defined by
        the file is created immediately for local file urls. Remote urls are
        loaded asynchronously, listen to the **objectCreated**  signal to
        determine when the object tree is ready.

        If an error occurs, the **objectCreated**  signal is emitted with a null
        pointer as parameter and error messages are printed with **qWarning** .
        """
        ...

    @typing.overload
    def load(self, filePath: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#load-1

        **[slot] void QQmlApplicationEngine::load(const QString & filePath )**

        Loads the root QML file located at **filePath**. **filePath** must be a
        path to a local file. If **filePath** is a relative path, it is taken as
        relative to the application's working directory. The object tree defined
        by the file is instantiated immediately.

        If an error occurs, error messages are printed with **qWarning** .
        """
        ...

    def rootObjects(self) -> typing.List[QtCore.QObject]:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#rootObjects

        **QList<QObject *> QQmlApplicationEngine::rootObjects() const**

        Returns a list of all the root objects instantiated by the
        **QQmlApplicationEngine** . This will only contain objects loaded via
        **load** () or a convenience constructor.

        **Note:** In Qt versions prior to 5.9, this function is marked as
        non-`const`.
        """
        ...

    @property
    def objectCreated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlapplicationengine.html#objectCreated

        **[signal] void QQmlApplicationEngine::objectCreated(QObject * object ,
        const QUrl & url )**

        This signal is emitted when an object finishes loading. If loading was
        successful, **object** contains a pointer to the loaded object,
        otherwise the pointer is NULL.

        The **url** to the component the **object** came from is also provided.

        **Note:** If the path to the component was provided as a **QString**
        containing a relative path, the **url** will contain a fully resolved
        path to the file.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QIntValidator(QValidator):
    """
    https://doc.qt.io/qt-6/qintvalidator.html

    **Detailed Description**

    Example of use:

    **QValidator**  *validator = new **QIntValidator** (100, 999, this);
    **QLineEdit**  *edit = new **QLineEdit** (this);

        // the edit
    lineedit will only accept integers between 100 and 999
    edit->setValidator(validator);

    Below we present some examples of validators. In practice they would
    normally be associated with a widget as in the example above.

    **QString**  str;
        int pos = 0;
        **QIntValidator**  v(100, 900, this);
    str = "1";
        v.validate(str, pos);     // returns Intermediate
        str =
    "012";
        v.validate(str, pos);     // returns Intermediate

        str =
    "123";
        v.validate(str, pos);     // returns Acceptable
        str = "678";
    v.validate(str, pos);     // returns Acceptable

        str = "999";
    v.validate(str, pos);    // returns Intermediate

        str = "1234";
    v.validate(str, pos);     // returns Invalid
        str = "-123";
    v.validate(str, pos);     // returns Invalid
        str = "abc";
    v.validate(str, pos);     // returns Invalid
        str = "12cm";
    v.validate(str, pos);     // returns Invalid

    Notice that the value `999` returns Intermediate. Values consisting of a
    number of digits equal to or less than the max value are considered
    intermediate. This is intended because the digit that prevents a number from
    being in range is not necessarily the last digit typed. This also means that
    an intermediate number can have leading zeros.

    The minimum and maximum values are set in one call with **setRange** (), or
    individually with **setBottom** () and **setTop** ().

    QIntValidator uses its **locale** () to interpret the number. For example,
    in Arabic locales, QIntValidator will accept Arabic digits.

    **Note:** The **QLocale::NumberOptions**  set on the **locale** () also
    affect the way the number is interpreted. For example, since
    **QLocale::RejectGroupSeparator**  is not set by default, the validator will
    accept group separators. It is thus recommended to use **QLocale::toInt** ()
    to obtain the numeric value.

    **See also** **QDoubleValidator** , **QRegularExpressionValidator** ,
    **QLocale::toInt** (), and **Line Edits Example** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#QIntValidator

        **QIntValidator::QIntValidator(QObject * parent = nullptr)**

        Constructs a validator with a **parent** object that accepts all
        integers.
        """
        ...

    @typing.overload
    def __init__(
        self, bottom: int, top: int, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#QIntValidator-1

        **QIntValidator::QIntValidator(int minimum , int maximum , QObject *
        parent = nullptr)**

        Constructs a validator with a **parent** , that accepts integers from
        **minimum** to **maximum** inclusive.
        """
        ...

    def top(self) -> int:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#top-prop

        **top : int**

        This property holds the validator's highest acceptable value

        By default, this property's value is derived from the highest signed
        integer available (typically 2147483647).

        **Access functions:**

        int **top** () const
        void **setTop** (int)

        **Notifier signal:**

        void **topChanged** (int **top** )

        **See also** **setRange** ().

        **Member Function Documentation**
        """
        ...

    def bottom(self) -> int:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#bottom-prop

        **bottom : int**

        This property holds the validator's lowest acceptable value

        By default, this property's value is derived from the lowest signed
        integer available (typically -2147483647).

        **Access functions:**

        int **bottom** () const
        void **setBottom** (int)

        **Notifier signal:**

        void **bottomChanged** (int **bottom** )

        **See also** **setRange** ().
        """
        ...

    def setRange(self, bottom: int, top: int) -> None:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#setRange

        **void QIntValidator::setRange(int bottom , int top )**

        Sets the range of the validator to only accept integers between
        **bottom** and **top** inclusive.
        """
        ...

    def setTop(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#top-prop

        **top : int**

        This property holds the validator's highest acceptable value

        By default, this property's value is derived from the highest signed
        integer available (typically 2147483647).

        **Access functions:**

        int **top** () const
        void **setTop** (int)

        **Notifier signal:**

        void **topChanged** (int **top** )

        **See also** **setRange** ().

        **Member Function Documentation**
        """
        ...

    def setBottom(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#bottom-prop

        **bottom : int**

        This property holds the validator's lowest acceptable value

        By default, this property's value is derived from the lowest signed
        integer available (typically -2147483647).

        **Access functions:**

        int **bottom** () const
        void **setBottom** (int)

        **Notifier signal:**

        void **bottomChanged** (int **bottom** )

        **See also** **setRange** ().
        """
        ...

    def fixup(self, input: str) -> str:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#fixup

        **[override virtual] void QIntValidator::fixup(QString & input ) const**

        Reimplements: **QValidator::fixup(QString &input) const** .
        """
        ...

    def validate(self, a0: str, a1: int) -> typing.Tuple[QValidator.State, str, int]:
        """
        https://doc.qt.io/qt-6/qintvalidator.html#validate

        **[override virtual] QValidator::State QIntValidator::validate(QString &
        input , int & pos ) const**

        Reimplements: **QValidator::validate(QString &input, int &pos) const** .

        Returns **Acceptable**  if the **input** is an integer within the valid
        range. If **input** has at most as many digits as the top of the range,
        or is a prefix of an integer in the valid range, returns
        **Intermediate** . Otherwise, returns **Invalid** .

        If the valid range consists of just positive integers (e.g., 32 to 100)
        and **input** is a negative integer, then Invalid is returned. (On the
        other hand, if the range consists of negative integers (e.g., -100 to
        -32) and **input** is a positive integer, then Intermediate is returned,
        because the user might be just about to type the minus (especially for
        right-to-left languages).

        Similarly, if the valid range is between 46 and 53, then 41 and 59 will
        be evaluated as **Intermediate** , as otherwise the user wouldn't be
        able to change a value from 49 to 51.

        int pos = 0;

            s = "abc";
            v.validate(s, pos);    // returns
        Invalid

            s = "5";
            v.validate(s, pos);    // returns
        Intermediate

            s = "50";
            v.validate(s, pos);    // returns
        Acceptable

        By default, the **pos** parameter is not used by this validator.
        """
        ...

    @property
    def bottomChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def topChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtBluetooth import *
import enum


class QLowEnergyServiceData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergyservicedata.html

    **Detailed Description**

    An Object of this class provides a service to be added to a GATT server via
    **QLowEnergyController::addService** ().
    """

    class ServiceType(enum.Enum):
        ServiceTypePrimary: QLowEnergyServiceData = ...
        ServiceTypeSecondary: QLowEnergyServiceData = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#QLowEnergyServiceData

        **QLowEnergyServiceData::QLowEnergyServiceData()**

        Creates a new invalid object of this class.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyServiceData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#QLowEnergyServiceData-
        1

        **QLowEnergyServiceData::QLowEnergyServiceData(const
        QLowEnergyServiceData & other )**

        Constructs a new object of this class that is a copy of **other**.
        """
        ...

    def swap(self, other: "QLowEnergyServiceData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#swap

        **void QLowEnergyServiceData::swap(QLowEnergyServiceData & other )**

        Swaps this object with **other**.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#isValid

        **bool QLowEnergyServiceData::isValid() const**

        Returns `true` if this service is has a non-null UUID.
        """
        ...

    def addCharacteristic(self, characteristic: QLowEnergyCharacteristicData) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#addCharacteristic

        **void QLowEnergyServiceData::addCharacteristic(const
        QLowEnergyCharacteristicData & characteristic )**

        Adds **characteristic** to the list of characteristics, if it is valid.

        **See also** **setCharacteristics** ().
        """
        ...

    def setCharacteristics(
        self, characteristics: typing.Iterable[QLowEnergyCharacteristicData]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#setCharacteristics

        **void QLowEnergyServiceData::setCharacteristics(const
        QList<QLowEnergyCharacteristicData> & characteristics )**

        Sets the list of characteristics to **characteristics**. Only valid
        characteristics are considered.

        **See also** **characteristics** () and **addCharacteristic** ().
        """
        ...

    def characteristics(self) -> typing.List[QLowEnergyCharacteristicData]:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#characteristics

        **QList<QLowEnergyCharacteristicData>
        QLowEnergyServiceData::characteristics() const**

        Returns the list of characteristics.

        **See also** **setCharacteristics** ().
        """
        ...

    def addIncludedService(self, service: QLowEnergyService) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#addIncludedService

        **void QLowEnergyServiceData::addIncludedService(QLowEnergyService *
        service )**

        Adds **service** to the list of included services. The **service**
        object must have been returned from a call to
        **QLowEnergyController::addService** . This requirement prevents
        circular includes (which are forbidden by the Bluetooth specification),
        and also helps to support the use case of including more than one
        service of the same type.

        **See also** **setIncludedServices** ().
        """
        ...

    def setIncludedServices(self, services: typing.Iterable[QLowEnergyService]) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#setIncludedServices

        **void QLowEnergyServiceData::setIncludedServices(const
        QList<QLowEnergyService *> & services )**

        Sets the list of included services to **services**. All objects in this
        list must have been returned from a call to
        **QLowEnergyController::addService** .

        **See also** **includedServices** () and **addIncludedService** ().
        """
        ...

    def includedServices(self) -> typing.List[QLowEnergyService]:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#includedServices

        **QList<QLowEnergyService *> QLowEnergyServiceData::includedServices()
        const**

        Returns the list of included services.

        **See also** **setIncludedServices** ().
        """
        ...

    def setUuid(self, uuid: QBluetoothUuid) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#setUuid

        **void QLowEnergyServiceData::setUuid(const QBluetoothUuid & uuid )**

        Sets the UUID of this service to **uuid**.

        **See also** **uuid** ().
        """
        ...

    def uuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#uuid

        **QBluetoothUuid QLowEnergyServiceData::uuid() const**

        Returns the UUID of this service.

        **See also** **setUuid** ().
        """
        ...

    def setType(self, type: "QLowEnergyServiceData.ServiceType") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#setType

        **void QLowEnergyServiceData::setType(QLowEnergyServiceData::ServiceType
        type )**

        Sets the type of this service to **type**.

        **See also** **type** ().
        """
        ...

    def type(self) -> "QLowEnergyServiceData.ServiceType":
        """
        https://doc.qt.io/qt-6/qlowenergyservicedata.html#type

        **QLowEnergyServiceData::ServiceType QLowEnergyServiceData::type()
        const**

        Returns the type of this service.

        **See also** **setType** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtOpenGL import *
import enum


class QOpenGLShader(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopenglshader.html

    **Detailed Description**

    This class supports shaders written in the OpenGL Shading Language (GLSL)
    and in the OpenGL/ES Shading Language (GLSL/ES).

    QOpenGLShader and **QOpenGLShaderProgram**  shelter the programmer from the
    details of compiling and linking vertex and fragment shaders.

    **See also** **QOpenGLShaderProgram** .
    """

    class ShaderTypeBit(enum.Flag):
        Vertex: QOpenGLShader = ...
        Fragment: QOpenGLShader = ...
        Geometry: QOpenGLShader = ...
        TessellationControl: QOpenGLShader = ...
        TessellationEvaluation: QOpenGLShader = ...
        Compute: QOpenGLShader = ...

    def __init__(
        self,
        type: "QOpenGLShader.ShaderTypeBit",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#QOpenGLShader

        **QOpenGLShader::QOpenGLShader(QOpenGLShader::ShaderType type , QObject
        * parent = nullptr)**

        Constructs a new QOpenGLShader object of the specified **type** and
        attaches it to **parent**. If shader programs are not supported,
        **QOpenGLShaderProgram::hasOpenGLShaderPrograms** () will return false.

        This constructor is normally followed by a call to **compileSourceCode**
        () or **compileSourceFile** ().

        The shader will be associated with the current **QOpenGLContext** .

        **See also** **compileSourceCode** () and **compileSourceFile** ().
        """
        ...

    @staticmethod
    def hasOpenGLShaders(
        type: "QOpenGLShader.ShaderTypeBit",
        context: typing.Optional[QtGui.QOpenGLContext] = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#hasOpenGLShaders

        **[static] bool
        QOpenGLShader::hasOpenGLShaders(QOpenGLShader::ShaderType type ,
        QOpenGLContext * context = nullptr)**

        Returns `true` if shader programs of type **type** are supported on this
        system; false otherwise.

        The **context** is used to resolve the GLSL extensions. If **context**
        is `nullptr`, then **QOpenGLContext::currentContext** () is used.
        """
        ...

    def shaderId(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#shaderId

        **GLuint QOpenGLShader::shaderId() const**

        Returns the OpenGL identifier associated with this shader.

        **See also** **QOpenGLShaderProgram::programId** ().
        """
        ...

    def log(self) -> str:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#log

        **QString QOpenGLShader::log() const**

        Returns the errors and warnings that occurred during the last compile.

        **See also** **compileSourceCode** () and **compileSourceFile** ().
        """
        ...

    def isCompiled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#isCompiled

        **bool QOpenGLShader::isCompiled() const**

        Returns `true` if this shader has been compiled; false otherwise.

        **See also** **compileSourceCode** () and **compileSourceFile** ().
        """
        ...

    def sourceCode(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#sourceCode

        **QByteArray QOpenGLShader::sourceCode() const**

        Returns the source code for this shader.

        **See also** **compileSourceCode** ().
        """
        ...

    def compileSourceFile(self, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#compileSourceFile

        **bool QOpenGLShader::compileSourceFile(const QString & fileName )**

        Sets the source code for this shader to the contents of **fileName** and
        compiles it. Returns `true` if the file could be opened and the source
        compiled, false otherwise.

        **See also** **compileSourceCode** ().
        """
        ...

    @typing.overload
    def compileSourceCode(self, source: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#compileSourceCode

        **bool QOpenGLShader::compileSourceCode(const char * source )**

        Sets the **source** code for this shader and compiles it. Returns `true`
        if the source was successfully compiled, false otherwise.

        **See also** **compileSourceFile** ().
        """
        ...

    @typing.overload
    def compileSourceCode(self, source: str) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshader.html#compileSourceCode-1

        **bool QOpenGLShader::compileSourceCode(const QByteArray & source )**

        This is an overloaded function.

        Sets the **source** code for this shader and compiles it. Returns `true`
        if the source was successfully compiled, false otherwise.

        **See also** **compileSourceFile** ().
        """
        ...

    def shaderType(self) -> "QOpenGLShader.ShaderTypeBit":
        """
        https://doc.qt.io/qt-6/qopenglshader.html#shaderType

        **QOpenGLShader::ShaderType QOpenGLShader::shaderType() const**

        Returns the type of this shader.
        """
        ...
